﻿using System.Drawing;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraTreeList;
using DevExpress.XtraTreeList.Columns;
using DevExpress.XtraTreeList.Data;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.treeList.DataSource = SalesData.GetSalesDataList();

            TreeListColumn changeColumn = new TreeListColumn();

            changeColumn.UnboundType             = UnboundColumnType.Decimal;
            changeColumn.Visible                 = true;
            changeColumn.OptionsColumn.AllowEdit = false;
            changeColumn.FieldName               = "ChangeFromPrevYear";
            changeColumn.Caption                 = "Change from Previous Year";
            changeColumn.Format.FormatType       = FormatType.Numeric;
            changeColumn.Format.FormatString     = "p2";

            this.thisYearBand.Columns.Add(changeColumn);

            this.treeList.CustomUnboundColumnData += treeList_CustomUnboundColumnData;

            this.treeList.ForceInitialize();

            changeColumn.AppearanceHeader.Font    = new Font(changeColumn.AppearanceHeader.Font, FontStyle.Bold);
            changeColumn.AppearanceCell.BackColor = Color.LightYellow;

            this.treeList.BestFitColumns();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 트리 리스트 언바운드 컬럼 데이터 커스텀 설정하기 - treeList_CustomUnboundColumnData(sender, e)

        /// <summary>
        /// 트리 리스트 언바운드 컬럼 데이터 커스텀 설정하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void treeList_CustomUnboundColumnData(object sender, TreeListCustomColumnDataEventArgs e)
        {
            if(e.IsGetData && e.Column.FieldName == "ChangeFromPrevYear")
            {
                SalesData salesData = e.Row as SalesData;

                if(salesData == null)
                {
                    return;
                }

                e.Value = (salesData.MarchSales - salesData.MarchSalesPrev) / salesData.MarchSalesPrev;
            }
        }

        #endregion
    }
}